summaryrefslogtreecommitdiffstats
path: root/chrome/browser/login_prompt.cc
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/login_prompt.cc
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/login_prompt.cc')
-rw-r--r--chrome/browser/login_prompt.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/chrome/browser/login_prompt.cc b/chrome/browser/login_prompt.cc
index fcf9696..8a52d5d 100644
--- a/chrome/browser/login_prompt.cc
+++ b/chrome/browser/login_prompt.cc
@@ -14,7 +14,7 @@
#include "chrome/browser/tab_contents/constrained_window.h"
#include "chrome/browser/tab_contents/navigation_controller.h"
#include "chrome/browser/tab_contents/tab_util.h"
-#include "chrome/browser/tab_contents/web_contents.h"
+#include "chrome/browser/tab_contents/tab_contents.h"
#include "chrome/browser/views/login_view.h"
#include "chrome/common/chrome_switches.h"
#include "chrome/common/l10n_util.h"
@@ -107,11 +107,11 @@ class LoginHandlerImpl : public LoginHandler,
SendNotifications();
}
- // Returns the WebContents that needs authentication.
- WebContents* GetWebContentsForLogin() {
+ // Returns the TabContents that needs authentication.
+ TabContents* GetTabContentsForLogin() {
DCHECK(MessageLoop::current() == ui_loop_);
- return tab_util::GetWebContentsByID(render_process_host_id_,
+ return tab_util::GetTabContentsByID(render_process_host_id_,
tab_contents_id_);
}
@@ -263,7 +263,7 @@ class LoginHandlerImpl : public LoginHandler,
DCHECK(MessageLoop::current() == ui_loop_);
NotificationService* service = NotificationService::current();
- WebContents* requesting_contents = GetWebContentsForLogin();
+ TabContents* requesting_contents = GetTabContentsForLogin();
if (!requesting_contents)
return;
@@ -309,7 +309,7 @@ class LoginHandlerImpl : public LoginHandler,
PasswordForm password_form_;
// Points to the password manager owned by the TabContents requesting auth.
- // Can be null if the TabContents is not a WebContents.
+ // Can be null if the TabContents is not a TabContents.
// This should only be accessed on the ui_loop_.
PasswordManager* password_manager_;
@@ -336,7 +336,7 @@ class LoginDialogTask : public Task {
}
void Run() {
- WebContents* parent_contents = handler_->GetWebContentsForLogin();
+ TabContents* parent_contents = handler_->GetTabContentsForLogin();
if (!parent_contents) {
// The request was probably cancelled.
return;
@@ -352,7 +352,7 @@ class LoginDialogTask : public Task {
// Tell the password manager to look for saved passwords.
PasswordManager* password_manager =
- parent_contents->AsWebContents()->GetPasswordManager();
+ parent_contents->GetPasswordManager();
// Set the model for the login view. The model (password manager) is owned
// by the view's parent TabContents, so natural destruction order means we
// don't have to worry about calling SetModel(NULL), because the view will